PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions with links to the structures/unions they belong to:

### - s -

- s() : Parameter
- s2() : Segment_25
- s2_extended() : WideSegment_25
- sameNetAs() : Pin
- saveFlags() : NavPoint
- scheduleSnapshot() : GLWidget
- search() : AStar
- seed() : Env, EnvPCB
- segment2() : Connection
- Segment_25() : Segment_25
- select() : ObjectsBVH
- set() : Parameter
- set_agent() : Env, EnvPCB
- set_task() : Env, EnvPCB
- setActionCountIncrement() : Action
- setActionLimit() : Agent
- setActionSpace() : Agent
- setActiveAreaBbox() : PCBoard
- setActiveLayer() : UIActions
- setActiveTool() : ActionTab
- setAllVisible() : RatsNest
- setAlpha() : NavMesh
- setAutocreateConnections() : PCBFactory
- setAutonomousAgent() : IUIApplication
- setBackDirection() : NavPoint
- setBaseDimensions() : Camera
- setBoard() : ActionTab, BrowserTab, Net
- setBottomView() : GLWidget
- setBox() : LayoutArea
- setCamera() : PCBoardMesh
- setCanPlaceViasInside() : Object
- setCanRouteInside() : Object
- setCenter() : Camera
- setChanged() : PCBoard
- setCheckStagnationBeforeSuccess() : RRRAgent
- setClearance() : Connection, Object
- setClearBoardBeforeRun() : Agent
- setColor() : Connection, NavMesh, NavTri, Net, Palette, ui::NavGrid
- setColorAuto() : Net
- setColorHL() : RatsNest
- setColors() : Component
- setCompound() : Pin
- setConnectionLRU() : Agent
- setContext() : RewardFunction, rewards::RouteLength
- setCost() : NavPoint
- setCosts() : NavGrid
- setDefaultLevel() : Logger
- setDefaultViaDiameter() : Connection, Track
- setDefaultWidth() : Connection, Track
- setDictItem() : py::Object
- setDone() : AStarVisitStatus
- setEdge() : NavPoint
- setElem() : py::Object
- setEnd() : Track
- setEpsilon() : Policy
- setExpansion() : Rasterizer< ROP >
- setExtraSet() : PCBoardMesh
- setFastActionMask() : Policy
- setFillAlpha() : PCBoardMesh
- setFixedTrackParams() : PCBFactory
- setFlags() : NavPoint
- setFloat() : NavPixel< chan_t >
- setFocus() : StateRepresentation
- setForceDesignRes() : PCBFactory
- setGranularity() : StepLock
- setHistoryCostDecay() : RRRAgent
- setHistoryCostIncrement() : RRRAgent
- setHistoryCostMax() : RRRAgent
- setHL() : RatsNest
- setId() : Connection, Net, Object
- setIgnoreLayoutBounds() : PCBFactory
- setIndex() : Action
- setItem() : py::Object
- setLayer() : Object, Segment_25
- setLayerAlpha() : GLWidget, RatsNest, RoutePainter
- setLayerColor() : RoutePainter
- setLayerMask() : Connection, Net
- setLayerMaskFromSignalType() : Net
- setLayerRange() : Object
- setLayoutAreaMaxMargin() : PCBFactory
- setLayoutAreaMinMargin() : PCBFactory
- setLegal() : Action, ActionSpace
- setLevel() : Logger
- setLimitRatsNest() : GLWidget
- setLimits() : Parameter
- setLineAlpha() : PCBoardMesh
- setLineSize() : ui::NavGrid
- setLineWidth() : PCBoardMesh, RatsNest, RoutePainter, RoutePainterLines, TriList
- setLoadFanout() : PCBFactory
- setLoadPolygonsAsBoxes() : PCBFactory
- setLoadTracks() : PCBFactory
- setLocation() : Component
- setLocked() : Connection
- setLockedView() : StateRepresentation
- setLockRoutedConnections() : PCBFactory
- setLockStepping() : UIActions
- setManagedConnections() : Agent, UserAgent
- setManagedConnectionsToUnrouted() : Agent
- setMaxIterations() : RRRAgent
- setMaxIterationsStagnant() : RRRAgent
- setMaxLayer() : LayoutArea
- setMinClearance() : Net
- setMinClearanceNets() : PCBoard
- setMinClearancePins() : PCBoard
- setMinIterations() : RRRAgent
- setMinTrackWidth() : Net, PCBoard
- setMinViaDiameter() : PCBoard
- setModified() : Track
- setName() : PCBoard
- setNet() : Pin
- setNetOverrides() : PCBFactory
- setNotifier() : Parameter
- setNumber() : Layer
- setNumLayers() : ActionTab, PCBoard, ViewTab
- setNumTidyIterations() : RRRAgent
- setOpen() : AStarVisitStatus
- setOrigin() : Camera, LayoutArea
- setOriginRelative() : Camera
- setOrtho() : math::Mat4
- setOwnsActions() : ActionSpace
- setParameter() : Agent, UserAgent
- setParameters() : Agent
- setParametersFrom() : Connection
- setPath() : LogFile, Track
- setPCB() : Agent, GLWidget, IUIApplication, UserAgent, Window
- setPin() : NavKeepoutCounts
- setPins() : ActionTab
- setPinTracks() : NavKeepoutCounts
- setPinVias() : NavKeepoutCounts
- setPoint() : Path
- setPoints() : Path
- setPointSize() : NavMesh
- setPolicy() : Agent
- setPolygonBbox() : LayoutArea
- setPrefix() : Logger
- setPreview() : UIActions
- setPreviewTrack() : UIActions
- setProgress() : ActionTab
- setPy() : AStarCosts, Track
- setPythonInterface() : Agent
- setRandomizeOrder() : RRRAgent
- setRange() : Via
- setRect() : LayoutArea
- setRectifySegmentsDegrees() : PCBFactory
- setReferenceLen() : Connection
- setRefPoint() : NavPoint
- setRewardFn() : Agent
- setRoute() : NavKeepoutCounts
- setRouted() : Connection
- setRouteMode() : UIActions
- setRouteTracks() : NavKeepoutCounts
- setRouteVias() : NavKeepoutCounts
- setRunArgs() : Agent
- setScore() : NavPoint
- setSegmentCapsMask() : Track
- setSegments() : Track
- setSelected() : Object
- setSelection() : UIActions
- setSelectionLayer() : UIActions
- setSelectionType() : UIActions
- setShape() : Object
- setSignalType() : Net
- setSize() : LayoutArea
- setSourceFilePath() : PCBoard
- setSpacings() : NavGrid
- setStart() : Track
- setStateRepresentation() : Agent
- setStateRepresentationParams() : Agent, UserAgent
- setTarget() : Logger
- setTemperature() : Policy
- setTimeout() : Agent
- setTimeoutExpired() : Agent
- setTimeoutMS() : UIActions
- setTopologies() : PCBFactory
- setTrack() : Connection
- setTrainingMode() : Agent
- setType() : Layer
- setUIElement() : UIActions
- setUndo() : Action
- setUnitLength_nm() : PCBFactory
- setVertices() : NavTri
- setViaCost() : UIActions
- setViaDiameter() : Net
- setViaExtent() : Net
- setVias() : Track
- setView() : Camera
- setViolationCostInf() : AStarCosts
- setVisible() : Parameter
- setVisualizeAStar() : NavMesh
- setWriteSeq() : NavPoint
- setXYBiasNone() : AStarCosts
- setZFar() : Camera
- setZNear() : Camera
- setZoom() : Camera
- setZRange() : Camera
- Shaders() : Shaders
- sharesLayer() : Object
- shortcutBetween() : Track
- shouldAdd() : ResultCollection
- show() : IUIApplication
- showFootprints() : GLWidget
- showGridAStar() : GLWidget
- showGridLines() : GLWidget
- showGridPoints() : GLWidget
- showRatsNest() : GLWidget
- showTriangulation() : GLWidget
- shrink() : ActionCache< Data >
- signal() : StepLock
- signalType() : Net
- size() : ActionSet, ActionSpace, LayoutArea, Palette, py::NPArray< T >
- sizeInBytes() : NavImage< chan_t >
- skipspace() : DSNParserBase
- skipspaceRev() : DSNParserBase
- sleepForActionDelay() : UserSettings
- slowdownToSliderPosition() : ViewTab
- snapToEnd() : Track
- snapToEndpoint() : Track
- snapToMidPoint() : UniformGrid25
- snapToStart() : Track
- sort_name() : Connection
- sortConnections() : Net
- source() : Connection, Segment_25, WideSegment_25
- source_2() : Segment_25, WideSegment_25
- sourceCap() : WideSegment_25
- sourceComponent() : Connection
- sourcePin() : Connection
- space() : ActionSet
- squared_distance() : AShape, CircleEx, Connection, IsoRectEx, Path, PolygonEx, TriangleEx, WideSegment_25
- squared_length() : Segment_25
- squared_radius() : Via
- squared_width() : WideSegment_25
- start() : Track
- startExclusiveTask() : IUIApplication
- startsWithVia() : Track
- startTimer() : Agent
- step() : Agent, Env, EnvPCB, UserAgent
- StepLock() : StepLock
- store() : ActionCache< Data >
- str() : Action::Result, AShape, CircleEx, Color, Component, Connection, dsn::Data, dsn::Image, dsn::Layer, dsn::Net, dsn::Padstack, dsn::Path, dsn::PCB, dsn::Pin, dsn::Placement, dsn::Shape, dsn::Structure, GridDirection, IsoRectEx, Layer, math::Mat4, NavGrid, NavPoint, Net, NetOverrides, Object, Path, Pin, PolygonEx, ResultRecord, Track, TriangleEx, UserSettings, Via, WideSegment_25
- stream() : LogFile
- stride() : py::NPArray< T >
- String() : Token
- sumViolationArea() : NavGrid, PCBoard
- swapWL() : WideSegment_25